#
# django-codenerix-payments
#
# Codenerix GNU
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


def url_path(url, action):
    return "/{}action/[a-zA-Z0-9]+/{}/$".format(url, action)


def url_success(url):
    return url_path(url, "success")


def url_confirm(url):
    return url_path(url, "confirm")


def url_cancel(url):
    return url_path(url, "cancel")



import os

from setuptools import setup

import codenerix_payments

with open(os.path.join(os.path.dirname(__file__), "README.rst")) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name="django_codenerix_payments",
    version=codenerix_payments.__version__,
    packages=["codenerix_payments"],
    include_package_data=True,
    zip_safe=False,
    license="Apache License Version 2.0",
    description="Codenerix Payments is a module that enables CODENERIX "
    "to manage payments and let clients to pay online.",
    long_description=README,
    url="https://github.com/codenerix/django-codenerix-payments",
    author=", ".join(codenerix_payments.__authors__),
    keywords=[
        "django",
        "codenerix",
        "management",
        "erp",
        "crm",
        "payments",
    ],
    platforms=["OS Independent"],
    classifiers=[
        "Environment :: Web Environment",
        "Framework :: Django",
        "Framework :: Django :: 4.0",
        "Intended Audience :: Developers",
        "License :: Other/Proprietary License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
    ],
    install_requires=[
        "django-codenerix>=5.0.23",
        "paypalrestsdk",
        "oss2",
        "rsa",
        "yop-python-sdk>=4.3.0",
        "cryptography",
    ],
)
